| Title: | Data and code for the book, The Sharpe Ratio: Statistics and Applications |
|---|---|
| Description: | Publicly available Market data, mostly compiled by Kenneth French, and loaded from Quandl. |
| Authors: | Steven E. Pav [aut, cre] (ORCID: <https://orcid.org/0000-0002-4197-6195>) |
| Maintainer: | Steven E. Pav <[email protected]> |
| License: | LGPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-22 08:28:29 UTC |
| Source: | https://github.com/shabbychef/tsrsa |
The daily returns of the 4 Fama French Factors: Market, the cap factor SMB, the growth factor HML, and the momentum factor UMD.
dff4dff4
An xts object with 24,795 observations and 5 columns.
The data run from January, 1927 through December, 2020.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
MktThe Market daily return. Note that the risk free rate has been added back to the excess returns published by the upstream source.
SMBThe cap factor daily return.
HMLThe growth factor daily return.
UMDThe momentum factor daily return.
RFThe risk-free rate, presumably as an daily rate, though note that no corrections have been made for weekend effects when adding the risk-free rate back to the market rate.
Steven E. Pav [email protected]
Kenneth French data library. See http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html, data description at http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/f-f_factors.html.
## Not run: data(dff4) str(dff4) ## End(Not run)## Not run: data(dff4) str(dff4) ## End(Not run)
The daily closing value of the CBOE VIX index.
dvixdvix
An xts object with 7,809 observations and 1 columns.
The data run from January, 1990 through December, 2020.
The columns are defined as follows:
VIXThe closing value of the VIX index. From January 2004 onward, the data are from the modern definition of the VIX index. The data from before 2004 are sourced from the back-computed data archive on CBOE.
Steven E. Pav [email protected]
## Not run: data(dvix) str(dvix) ## End(Not run)## Not run: data(dvix) str(dvix) ## End(Not run)
The yearly excess returns of the Market, aligned with a number of lagging independent variables which have been posited to be predictive of the excess returns.
gwgw
An xts object with 215 observations and 23 columns.
The data are annual and span from 1802 through 2016.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
The columns are defined in the paper, but are roughly as follows:
cpiThe Consumer price index
goldThe spot price of gold
inflInflation as a percent?
tbillThe Treasury bill rate?
ltyld10???
ltrate???
callmoney????
aaa????
baa????
corprate????
corprate.i????
sp500indexThe closing value of the S&P 500 index.
sp500d12????
sp500e12????
vwm????
vwx????
svar????
bkmk????
ntis????
eqis????
csp????
cay????
ik????
Steven E. Pav [email protected]
Ivo Welch's data page, http://www.ivo-welch.info/professional/goyal-welch/.
Welch, Ivo and Goyal, Amit. "A Comprehensive Look at The Empirical Performance of Equity Premium Prediction." The Review of Financial Studies 21 , no. 4 (2007): 1455-1508. https://doi.org/10.1093/rfs/hhm014
## Not run: data(gw) str(gw) ## End(Not run)## Not run: data(gw) str(gw) ## End(Not run)
The monthly returns of the 4 Fama French Factors: Market, the cap factor SMB, the growth factor HML, and the momentum factor UMD.
mff4mff4
An xts object with 1,128 observations and 5 columns.
The data run from January, 1927 through December, 2020.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
MktThe Market monthly return. Note that the risk free rate has been added back to the excess returns published by the upstream source.
SMBThe cap factor monthly return.
HMLThe growth factor monthly return.
UMDThe momentum factor monthly return.
RFThe risk-free rate, presumably as a monthly rate. The average value is arround 0.28, corresponding to an annualized rate of around 3.3%.
Steven E. Pav [email protected]
Kenneth French data library. See http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html, data description at http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/f-f_factors.html.
## Not run: data(mff4) str(mff4) ## End(Not run)## Not run: data(mff4) str(mff4) ## End(Not run)
The monthly returns of the 6 Fama French Factors: Market, the cap factor SMB, the growth factor HML, the momentum factor UMD, the profitability factor RMW, and the invesment factor CMA.
mff6mff6
An xts object with 690 observations and 7 columns.
The data run from July, 1963 through December, 2020.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
MktThe Market monthly return. Note that the risk free rate has been added back to the excess returns published by the upstream source.
SMBThe cap factor monthly return.
HMLThe growth factor monthly return.
UMDThe momentum factor monthly return.
RMWThe profitability factor monthly return.
CMAThe investment factor monthly return.
RFThe risk-free rate, presumably as a monthly rate. The average value is arround 0.39, corresponding to an annualized rate of around 4.7%.
Steven E. Pav [email protected]
Kenneth French data library. See http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html, and data description at http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/f-f_5_factors_2x3.html.
## Not run: data(mff6) str(mff6) ## End(Not run)## Not run: data(mff6) str(mff6) ## End(Not run)
The monthly returns of 10 industries: Nondurable goods, durable goods, Manufacturing, Energy, High Technology, Telecom, Retail, Healthcare, Utilities and Other.
mind10mind10
An xts object with 1,128 observations and 10 columns.
The data run from January, 1927 through December, 2020.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
NondurableGoodsThe monthly returns of the nondurable goods industry, published as “NoDur”.
DurableGoodsThe monthly returns of the durable goods industry, published as “Durbl”.
ManufacturingThe monthly returns of the Manufacturing industry, published as “Manuf”.
EnergyThe monthly returns of the Energy industry, published as “Enrgy”.
TechnologyThe monthly returns of the Technology industry, published as “HiTec”.
TelecomThe monthly returns of the Telecommunications industry, published as “Telcm”.
RetailThe monthly returns of the Retail industry, published as “Shops”.
HealthcareThe monthly returns of the Healthcare industry, published as “Hlth”.
UtilitiesThe monthly returns of the Utilities industry, published as “Utils”.
OtherThe monthly returns of the Other industry, published as “Other”.
These are not the “ex dividend” returns series.
Steven E. Pav [email protected]
Kenneth French data library. See http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html, data description at http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/det_10_ind_port.html.
## Not run: data(mind10) str(mind10) ## End(Not run)## Not run: data(mind10) str(mind10) ## End(Not run)
The monthly returns of 5 industries: Consumer, Manufacturing, High Technology, Healthcare and Other.
mind5mind5
An xts object with 1,128 observations and 5 columns.
The data run from January, 1927 through December, 2020.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
ConsumerThe monthly returns of the Consumer industry, published as “Cnsmr”.
ManufacturingThe monthly returns of the Manufacturing industry, published as “Manuf”.
TechnologyThe monthly returns of the Technology industry, published as “HiTec”.
HealthcareThe monthly returns of the Healthcare industry, published as “Hlth”.
OtherThe monthly returns of the Other industry, published as “Other”.
These are not the “ex dividend” returns series.
Steven E. Pav [email protected]
Kenneth French data library. See http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/data_library.html, data description at http://mba.tuck.dartmouth.edu/pages/faculty/ken.french/Data_Library/det_5_ind_port.html.
## Not run: data(mind5) str(mind5) ## End(Not run)## Not run: data(mind5) str(mind5) ## End(Not run)